"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Codable = void 0;
const iDecodable_1 = require("./iDecodable");
const update_1 = require("../update");
class Codable extends update_1.Updatable {
    constructor() {
        super();
    }
    get encode() {
        return this;
    }
    decode(json) {
        if (!(typeof json === "object" && json !== null)) {
            throw new Error(`decode object should be an object, but got ${json}`);
        }
        const object = json;
        const clone = this.clone;
        for (const key in object) {
            if (!(key in clone))
                continue;
            const property = clone[key];
            if (typeof property !== "object" || property == null) {
                clone[key] = object[key];
                continue;
            }
            if ((0, iDecodable_1.isDecodable)(property)) {
                clone[key] = property.decode(object[key]);
                continue;
            }
            if (!Array.isArray(property))
                continue;
            if (property.length === 0 || !(0, iDecodable_1.isDecodable)(property[0])) {
                clone[key] = object[key];
                continue;
            }
            if (!Array.isArray(object[key]))
                continue;
            clone[key] = object[key].map((value) => {
                return property[0].decode(value);
            });
        }
        return clone;
    }
}
exports.Codable = Codable;
//# sourceMappingURL=codable.js.map