"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const equatable_1 = require("./equatable");
const assertion_test_1 = require("./assertion.test");
(0, vitest_1.describe)("equals Tests", () => {
    class E extends equatable_1.Equatable {
        constructor(name, age) {
            super();
            this.name = name;
            this.age = age;
        }
    }
    (0, vitest_1.test)("同じ値の場合はtrue", () => {
        const e1 = new E("hello", 10);
        const e2 = new E("hello", 10);
        (0, assertion_test_1.assertEquals)(e1, e2);
    });
    (0, vitest_1.test)("異なるnameの場合はfalse", () => {
        const e1 = new E("hello", 10);
        const e2 = new E("world", 10);
        (0, assertion_test_1.assertNotEquals)(e1, e2);
    });
    (0, vitest_1.test)("異なるageの場合はfalse", () => {
        const e1 = new E("hello", 10);
        const e2 = new E("hello", 11);
        (0, assertion_test_1.assertNotEquals)(e1, e2);
    });
    class HasArray extends equatable_1.Equatable {
        constructor(array) {
            super();
            this.array = array;
        }
    }
    (0, vitest_1.test)("配列が同じ場合はtrue", () => {
        const e1 = new HasArray([1, 2, 3]);
        const e2 = new HasArray([1, 2, 3]);
        (0, assertion_test_1.assertEquals)(e1, e2);
    });
    (0, vitest_1.test)("配列の要素数が異なる場合はfalse", () => {
        const e1 = new HasArray([1, 2, 3]);
        const e2 = new HasArray([1, 2]);
        (0, assertion_test_1.assertNotEquals)(e1, e2);
    });
    (0, vitest_1.test)("配列の要素が一つでもが異なる場合はfalse", () => {
        const e1 = new HasArray([1, 2, 3]);
        const e2 = new HasArray([1, 2, 4]);
        (0, assertion_test_1.assertNotEquals)(e1, e2);
    });
    class HasEquatable extends equatable_1.Equatable {
        constructor(e) {
            super();
            this.e = e;
        }
    }
    (0, vitest_1.test)("プロパティでもequalsの場合はtrue", () => {
        const e1 = new HasEquatable(new E("hello", 10));
        const e2 = new HasEquatable(new E("hello", 10));
        (0, assertion_test_1.assertEquals)(e1, e2);
    });
    (0, vitest_1.test)("プロパティが異なる場合はfalse", () => {
        const e1 = new HasEquatable(new E("hello", 10));
        const e2 = new HasEquatable(new E("hello", 11));
        (0, assertion_test_1.assertNotEquals)(e1, e2);
    });
});
//# sourceMappingURL=equatable.test.js.map