"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const iEquatable_1 = require("./iEquatable");
class TestCase {
    constructor(a, b, expected) {
        this.a = a;
        this.b = b;
        this.expected = expected;
    }
    assert() {
        (0, vitest_1.expect)((0, iEquatable_1.equals)(this.a, this.b), this.message).toBe(this.expected);
    }
    get message() {
        return `a: ${String(this.a)}, b: ${String(this.b)}, expected: ${this.expected}`;
    }
}
(0, vitest_1.describe)("equals Tests", () => {
    (0, vitest_1.test)("booleanで比較可能", () => {
        const testCases = [
            new TestCase(true, true, true),
            new TestCase(true, false, false),
            new TestCase(false, true, false),
            new TestCase(false, false, true),
        ];
        testCases.forEach((testCase) => testCase.assert());
    });
    (0, vitest_1.test)("numberで比較可能", () => {
        const testCases = [
            new TestCase(1, 1, true),
            new TestCase(1, 2, false),
        ];
        testCases.forEach((testCase) => testCase.assert());
    });
    (0, vitest_1.test)("undefinedとnullは区別をつけない", () => {
        const testCases = [
            new TestCase(undefined, undefined, true),
            new TestCase(undefined, null, true),
            new TestCase(null, undefined, true),
        ];
        testCases.forEach((testCase) => testCase.assert());
    });
    (0, vitest_1.test)("stringの比較", () => {
        const testCases = [
            new TestCase("hello", "hello", true),
            new TestCase("hello", "world", false),
        ];
        testCases.forEach((testCase) => testCase.assert());
    });
    (0, vitest_1.test)("関数は参照値で比較", () => {
        const f = () => "world";
        const testCases = [
            new TestCase(() => "hello", () => "hello", false),
            new TestCase(f, f, true),
        ];
        testCases.forEach((testCase) => testCase.assert());
    });
    class True {
        constructor(name, age) {
            this.name = name;
            this.age = age;
        }
        equals(_) {
            return true;
        }
    }
    class False {
        constructor(name, age) {
            this.name = name;
            this.age = age;
        }
        equals(_) {
            return false;
        }
    }
    (0, vitest_1.test)("オブジェクトで比較", () => {
        const testCases = [
            new TestCase(new True("hello", 1), new True("hello", 1), true),
            new TestCase(new False("hello", 1), new False("hello", 1), false),
        ];
    });
});
//# sourceMappingURL=iEquatable.test.js.map