"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const none_1 = require("./none");
const some_1 = require("./some");
const result_1 = require("../result");
(0, vitest_1.describe)("None Tests", () => {
    (0, vitest_1.test)("getでErrorを投げる", () => {
        const option = (0, none_1.none)();
        (0, vitest_1.expect)(() => option.get).toThrowError("none to get");
    });
    (0, vitest_1.test)("valueでnullを返す", () => {
        const option = (0, none_1.none)();
        (0, vitest_1.expect)(option.value).toBeNull();
    });
    (0, vitest_1.test)("getOrElseで引数の値が返される", () => {
        const option = (0, none_1.none)();
        (0, vitest_1.expect)(option.getOrElse("world")).toBe("world");
    });
    (0, vitest_1.test)("orElseで引数の値が返される", () => {
        const option = (0, none_1.none)();
        (0, vitest_1.expect)(option.orElse((0, some_1.some)("world"))).toEqual((0, some_1.some)("world"));
    });
    (0, vitest_1.test)("isDefinedはfalse", () => {
        const option = (0, none_1.none)();
        (0, vitest_1.expect)(option.isDefined).toBeFalsy();
    });
    (0, vitest_1.test)("isEmptyはtrue", () => {
        const option = (0, none_1.none)();
        (0, vitest_1.expect)(option.isEmpty).toBeTruthy();
    });
    (0, vitest_1.test)("mapでnoneを返す", () => {
        const option = (0, none_1.none)();
        (0, vitest_1.expect)(option.map((value) => value * 2)).toEqual((0, none_1.none)());
    });
    (0, vitest_1.test)("flatMapでnoneを返す", () => {
        const option = (0, none_1.none)();
        (0, vitest_1.expect)(option.flatMap((value) => (0, some_1.some)(value * 2))).toEqual((0, none_1.none)());
    });
    (0, vitest_1.test)("none同士でequalsで比較するとtrueを返す", () => {
        const option1 = (0, none_1.none)();
        const option2 = (0, none_1.none)();
        (0, vitest_1.expect)(option1.equals(option2)).toBeTruthy();
    });
    (0, vitest_1.test)("noneとsomeでequalsで比較するとfalseを返す", () => {
        const option1 = (0, none_1.none)();
        const option2 = (0, some_1.some)(10);
        (0, vitest_1.expect)(option1.equals(option2)).toBeFalsy();
    });
    (0, vitest_1.test)("foldでnoneの場合は第一引数の関数が実行される", () => {
        const option = (0, none_1.none)();
        (0, vitest_1.expect)(option.fold(() => "none", (_) => "some")).toBe("none");
    });
    (0, vitest_1.test)("unwrapでErrorが投げられる", () => {
        const option = (0, none_1.none)();
        (0, vitest_1.expect)(() => option.unwrap(new Error("Error"))).toThrowError("Error");
    });
    (0, vitest_1.test)("toResultでfailureに変換する", () => {
        const option = (0, none_1.none)();
        (0, vitest_1.expect)(option.toResult(new Error("error"))).toEqual((0, result_1.failure)(new Error("error")));
    });
    (0, vitest_1.test)("decodeはnoneを返す", () => {
        const option = (0, none_1.none)();
        (0, vitest_1.expect)(option.decode({})).toEqual((0, none_1.none)());
    });
    (0, vitest_1.test)("encodeするとnullを返す", () => {
        (0, vitest_1.expect)((0, none_1.none)().encode).toBeNull();
    });
    (0, vitest_1.test)("encodeするとnullを返す", () => {
        (0, vitest_1.expect)((0, none_1.none)().encode).toBeNull();
    });
    (0, vitest_1.test)("compareはtrueを返す", () => {
        const option = (0, none_1.none)();
        (0, vitest_1.expect)(option.compare((0, none_1.none)())).toBeTruthy();
    });
});
//# sourceMappingURL=none.test.js.map