"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.failure = exports.Failure = void 0;
const optional_1 = require("../optional");
const equality_1 = require("../equality");
const clone_1 = require("../clone");
class Failure {
    constructor(error) {
        this.error = error;
        this.isSuccess = false;
        this.isFailure = true;
    }
    get get() {
        throw new Error("failure to get");
    }
    get getError() {
        return this.error;
    }
    map(_) {
        return this;
    }
    flatMap(_) {
        return this;
    }
    mapError(f) {
        return failure(f(this.error));
    }
    flatMapError(f) {
        return f(this.error);
    }
    equals(compared, _, comparisonFunc) {
        if (compared.isSuccess)
            return false;
        if (comparisonFunc === undefined) {
            return (0, equality_1.equals)(this.error, compared.getError);
        }
        return comparisonFunc(this.error, compared.getError);
    }
    get toOptional() {
        return (0, optional_1.none)();
    }
    get clone() {
        if ((0, clone_1.isClonable)(this.error)) {
            return failure(this.error.clone);
        }
        if (typeof this.error === "object") {
            return failure(Object.create(this.error));
        }
        return failure(this.error);
    }
}
exports.Failure = Failure;
function failure(error) {
    return new Failure(error);
}
exports.failure = failure;
//# sourceMappingURL=failure.js.map