"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const success_1 = require("./success");
const failure_1 = require("./failure");
const optional_1 = require("../optional");
const equality_1 = require("../equality");
(0, vitest_1.describe)("Success Tests", () => {
    (0, vitest_1.test)("getで値を取得できる", () => {
        const result = (0, success_1.success)(10);
        (0, vitest_1.expect)(result.get).toBe(10);
    });
    (0, vitest_1.test)("getErrorでエラーを投げる", () => {
        const result = (0, success_1.success)(10);
        (0, vitest_1.expect)(() => result.getError).toThrowError("success to getError");
    });
    (0, vitest_1.test)("mapで値を変換できる", () => {
        const result = (0, success_1.success)(10);
        (0, vitest_1.expect)(result.map((n) => `${n * 2}番`)).toEqual((0, success_1.success)("20番"));
    });
    (0, vitest_1.test)("flatMapで値を変換し平らにできる", () => {
        const result = (0, success_1.success)(10);
        (0, vitest_1.expect)(result.flatMap((n) => (0, success_1.success)(`${n * 2}番`))).toEqual((0, success_1.success)("20番"));
    });
    (0, vitest_1.test)("flatMapで値を変換し戻り値がFailureのときはFailureになる", () => {
        const result = (0, success_1.success)(10);
        (0, vitest_1.expect)(result.flatMap((n) => (0, failure_1.failure)(new Error()))).toEqual((0, failure_1.failure)(new Error()));
    });
    (0, vitest_1.test)("mapErrorで何も起こらない", () => {
        const result = (0, success_1.success)(10);
        const expected = (0, success_1.success)(10);
        const actual = result.mapError((error) => new Error(error.message + "mapError"));
        (0, vitest_1.expect)(actual).toEqual(expected);
    });
    (0, vitest_1.test)("flatMapErrorで何も起こらない", () => {
        const result = (0, success_1.success)(10);
        const expected = (0, success_1.success)(10);
        const actual = result.flatMapError((error) => (0, failure_1.failure)(new Error(error.message + "mapError")));
        (0, vitest_1.expect)(actual).toEqual(expected);
    });
    (0, vitest_1.test)("isSuccessでtrueを返し、isFailureでfalseを返す", () => {
        const result = (0, success_1.success)(10);
        (0, vitest_1.expect)(result.isSuccess).toBeTruthy();
        (0, vitest_1.expect)(result.isFailure).toBeFalsy();
    });
    (0, vitest_1.test)("equalsでsuccess同士で中身が同じならばtrueを返す", () => {
        const result1 = (0, success_1.success)(10);
        const result2 = (0, success_1.success)(10);
        (0, vitest_1.expect)(result1.equals(result2)).toBeTruthy();
    });
    (0, vitest_1.test)("equalsでsuccess同士で中身が異なればfalseを返す", () => {
        const result1 = (0, success_1.success)(10);
        const result2 = (0, success_1.success)(20);
        (0, vitest_1.expect)(result1.equals(result2)).toBeFalsy();
    });
    class E extends equality_1.Equatable {
        constructor(value) {
            super();
            this.value = value;
        }
    }
    (0, vitest_1.test)("equalsでsuccess同士でEquatableならばequalsで比較する", () => {
        const result1 = (0, success_1.success)(new E(10));
        const result2 = (0, success_1.success)(new E(10));
        (0, vitest_1.expect)(result1.equals(result2)).toBeTruthy();
    });
    (0, vitest_1.test)("equalsでfailureと比較するとfalseを返す", () => {
        const result1 = (0, success_1.success)(10);
        const result2 = (0, failure_1.failure)(10);
        (0, vitest_1.expect)(result1.equals(result2)).toBeFalsy();
    });
    (0, vitest_1.test)("equalsで第二引数に比較関数を渡すと、その関数で比較する", () => {
        const result1 = (0, success_1.success)(10);
        const result2 = (0, success_1.success)(20);
        (0, vitest_1.expect)(result1.equals(result2, (a, b) => a % 10 === b % 10)).toBeTruthy();
    });
    (0, vitest_1.test)("equalsで第二引数に比較関数を渡すと、その関数で比較する", () => {
        const result1 = (0, success_1.success)(10);
        const result2 = (0, success_1.success)(10);
        (0, vitest_1.expect)(result1.equals(result2, () => false)).toBeFalsy();
    });
    (0, vitest_1.test)("toOptionalでSomeを返す", () => {
        const result = (0, success_1.success)(10);
        (0, vitest_1.expect)(result.toOptional).toEqual((0, optional_1.some)(10));
    });
});
//# sourceMappingURL=success.test.js.map