"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.set = exports.Set = void 0;
const sequence_1 = require("../sequence");
class Set {
    constructor(seq) {
        this.seq = seq.distinct.sorted();
    }
    /** 引数と集合の要素の積集合を返す */
    intersection(other) {
        return set(other).filter((v) => this.contains(v));
    }
    /** 引数と集合の要素の和集合を返す */
    union(other) {
        return set(this.seq.concat(set(other).seq).distinct);
    }
    /** 引数がこの集合の部分集合であればtrueを返す */
    isSubset(other) {
        return set(other).every((v) => this.contains(v));
    }
    except(other) {
        return set(this.seq.filter((v) => !set(other).contains(v)));
    }
    /** 集合が空であればtrueを返す */
    get isEmpty() {
        return this.seq.isEmpty;
    }
    /** 集合が空でなければtrueを返す */
    get nonEmpty() {
        return this.seq.nonEmpty;
    }
    get clone() {
        return new Set(this.seq.clone);
    }
    /** 集合の要素数を返す */
    get count() {
        return this.seq.count;
    }
    get toSeq() {
        return this.seq;
    }
    /** 集合に加える */
    insert(element) {
        return new Set(this.seq.append(element));
    }
    map(f) {
        return new Set(this.seq.map((v, i, seq) => f(v, i, set(seq))));
    }
    flatMap(f) {
        return set(this.seq.flatMap((v, i, seq) => f(v, i, set(seq)).toSeq));
    }
    compactMap(f) {
        return set(this.seq.compactMap((v, i, seq) => f(v, i, set(seq))));
    }
    filter(f) {
        return new Set(this.seq.filter((v, i, seq) => f(v, i, set(seq))));
    }
    reduce(init, f) {
        return this.seq.reduce(init, (acc, v, i, seq) => f(acc, v, i, set(seq)));
    }
    every(f) {
        return this.seq.every((v, i, seq) => f(v, i, set(seq)));
    }
    some(f) {
        return this.seq.some((v, i, seq) => f(v, i, set(seq)));
    }
    sorted(comparator) {
        return this.seq.sorted(comparator);
    }
    max(comparator) {
        return this.seq.max(comparator);
    }
    min(comparator) {
        return this.seq.min(comparator);
    }
    contains(element) {
        return this.seq.contains(element);
    }
    find(f) {
        return this.seq.find((v, i, seq) => f(v, i, set(seq)));
    }
    [Symbol.iterator]() {
        return this.seq[Symbol.iterator]();
    }
    next() {
        return this.seq[Symbol.iterator]().next();
    }
    get encode() {
        return this.seq.encode;
    }
    decode(object) {
        return set(this.seq.decode(object));
    }
    equals(other) {
        return this.seq.equals(other.seq);
    }
}
exports.Set = Set;
function set(...elements) {
    if (elements.length === 0) {
        return new Set((0, sequence_1.seq)());
    }
    if (elements.length === 1) {
        if (Array.isArray(elements[0])) {
            // array: readonly T[]
            return new Set((0, sequence_1.seq)(elements[0]));
        }
        if (elements[0] instanceof sequence_1.Sequence) {
            // sequence: Sequence<T>
            return new Set(elements[0]);
        }
        if (elements[0] instanceof Set) {
            // set: Set<T>
            return elements[0];
        }
    }
    // elements: readonly T[]
    return new Set((0, sequence_1.seq)(elements));
}
exports.set = set;
//# sourceMappingURL=set.js.map